"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tracer = void 0;
const api_1 = require("@opentelemetry/api");
const sdk_trace_node_1 = require("@opentelemetry/sdk-trace-node");
const opentelemetry_cloud_trace_exporter_1 = require("@google-cloud/opentelemetry-cloud-trace-exporter");
const instrumentation_1 = require("@opentelemetry/instrumentation");
const instrumentation_dns_1 = require("@opentelemetry/instrumentation-dns");
const instrumentation_http_1 = require("@opentelemetry/instrumentation-http");
const instrumentation_express_1 = require("@opentelemetry/instrumentation-express");
const instrumentation_winston_1 = require("@opentelemetry/instrumentation-winston");
const sdk_trace_base_1 = require("@opentelemetry/sdk-trace-base");
const resources_1 = require("@opentelemetry/resources");
const semantic_conventions_1 = require("@opentelemetry/semantic-conventions");
const propagator_b3_1 = require("@opentelemetry/propagator-b3");
const utils_1 = require("./utils");
const tracer = (serviceName, { http = {
    portsToInstrument: [3000],
}, extraInstrumentations = [], debug = false, }) => {
    (0, instrumentation_1.registerInstrumentations)({
        instrumentations: [
            new instrumentation_dns_1.DnsInstrumentation(),
            new instrumentation_http_1.HttpInstrumentation({
                ignoreIncomingRequestHook: (req) => {
                    return !http.portsToInstrument.includes(req.socket.localPort || 0);
                },
            }),
            new instrumentation_express_1.ExpressInstrumentation(),
            new instrumentation_winston_1.WinstonInstrumentation(),
            ...(extraInstrumentations || []),
        ],
    });
    const provider = new sdk_trace_node_1.NodeTracerProvider({
        resource: new resources_1.Resource({
            [semantic_conventions_1.SemanticResourceAttributes.SERVICE_NAME]: serviceName,
            [semantic_conventions_1.SemanticResourceAttributes.SERVICE_INSTANCE_ID]: (0, utils_1.environmentVariable)("HOSTNAME", "local"),
        }),
    });
    provider.register({
        propagator: new propagator_b3_1.B3Propagator({
            injectEncoding: propagator_b3_1.B3InjectEncoding.MULTI_HEADER,
        }),
    });
    if ((0, utils_1.environmentVariable)("STACKDRIVER_TRACING_ENABLED", false)) {
        const exporter = new opentelemetry_cloud_trace_exporter_1.TraceExporter({
            resourceFilter: /^service\./,
        });
        provider.addSpanProcessor(new sdk_trace_base_1.BatchSpanProcessor(exporter));
    }
    if (debug) {
        api_1.diag.setLogger(new api_1.DiagConsoleLogger(), api_1.DiagLogLevel.DEBUG);
        provider.addSpanProcessor(new sdk_trace_base_1.BatchSpanProcessor(new sdk_trace_node_1.ConsoleSpanExporter()));
    }
};
exports.tracer = tracer;
