"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
describe("environmentVariable", () => {
    test("Should throw when environment variable does not exist", async () => {
        expect(() => (0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_NON_EXISTING")).toThrow("Missing environment variable 'COMMONS_NODEJS_TEST_NON_EXISTING'");
    });
    test("Should return fallback value when environment variable does not exist (string)", async () => {
        expect((0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_NON_EXISTING", "my-fallback")).toBe("my-fallback");
    });
    test("Should return fallback value when environment variable does not exist (number)", async () => {
        expect((0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_NON_EXISTING", 1)).toBe(1);
    });
    test("Should return fallback value when environment variable does not exist (boolean)", async () => {
        expect((0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_NON_EXISTING", false)).toBe(false);
    });
    test("Should return actual value when environment variable exists (string)", async () => {
        process.env["COMMONS_NODEJS_TEST_EXISTING"] = "actual-value";
        expect((0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_EXISTING", "my-fallback")).toBe("actual-value");
    });
    test("Should return actual value when environment variable exists (number)", async () => {
        process.env["COMMONS_NODEJS_TEST_EXISTING"] = "2";
        expect((0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_EXISTING", 1)).toBe(2);
    });
    test("Should return actual value when environment variable exists (boolean)", async () => {
        process.env["COMMONS_NODEJS_TEST_EXISTING"] = "true";
        expect((0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_EXISTING", false)).toBe(true);
    });
    test("should throw when environment variable contains an invalid type (number)", async () => {
        process.env["COMMONS_NODEJS_TEST_EXISTING"] = "not-a-number";
        expect(() => (0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_EXISTING", 1)).toThrow("Wrong type for environment variable 'COMMONS_NODEJS_TEST_EXISTING'");
    });
    test("should throw when environment variable contains an invalid type (boolean)", async () => {
        process.env["COMMONS_NODEJS_TEST_EXISTING"] = "not-a-boolean";
        expect(() => (0, utils_1.environmentVariable)("COMMONS_NODEJS_TEST_EXISTING", false)).toThrow("Wrong type for environment variable 'COMMONS_NODEJS_TEST_EXISTING'");
    });
});
describe("isValidEmail", () => {
    describe("Valid email addresses", () => {
        test("Standard email address", () => expect((0, utils_1.isValidEmail)("a@moreapp.dev")).toBeTruthy());
        test("Non-alphanumeric characters", () => expect((0, utils_1.isValidEmail)("a+-._&%'@moreapp.dev")).toBeTruthy());
        test("Shortest email address", () => expect((0, utils_1.isValidEmail)("a@b.co")).toBeTruthy());
        test("Subdomain", () => expect((0, utils_1.isValidEmail)("a@sub.domain.dev")).toBeTruthy());
        test("Subdomain with a dash", () => expect((0, utils_1.isValidEmail)("a@sub.dom-ain.dev")).toBeTruthy());
        test("Long TLD", () => expect((0, utils_1.isValidEmail)("a@b.business")).toBeTruthy());
        test("Diacritics", () => expect((0, utils_1.isValidEmail)("ẞçäöü@möręæppß.dev")).toBeTruthy());
        test("Casing", () => expect((0, utils_1.isValidEmail)("TØmÂs@mŒREÄPp.cOm")).toBeTruthy());
    });
    describe("Invalid email addresses", () => {
        test("Missing '@' character and domain", () => expect((0, utils_1.isValidEmail)("john")).toBeFalsy());
        test("Multiple '@' characters", () => expect((0, utils_1.isValidEmail)("a@b@moreapp.dev")).toBeFalsy());
        test("Ends with a '@' character", () => expect((0, utils_1.isValidEmail)("a@moreapp.dev@")).toBeFalsy());
        test("Empty", () => expect((0, utils_1.isValidEmail)("")).toBeFalsy());
        test("Whitespace before/after", () => expect((0, utils_1.isValidEmail)(" a@moreapp.dev ")).toBeFalsy());
        test("Newlines, tabs, ..., before/after", () => expect((0, utils_1.isValidEmail)("\n \ta@moreapp.dev\n ")).toBeFalsy());
        test("Missing '@' character", () => expect((0, utils_1.isValidEmail)("ab.com")).toBeFalsy());
        test("Double dot in domain", () => expect((0, utils_1.isValidEmail)("a@moreapp..com")).toBeFalsy());
        test("Too short TLD", () => expect((0, utils_1.isValidEmail)("a@b.c")).toBeFalsy());
        test("Missing local part", () => expect((0, utils_1.isValidEmail)("@moreapp.dev")).toBeFalsy());
        test("Too long", () => expect((0, utils_1.isValidEmail)("abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-abcdefghijklmnopqrstuvwxyz-@moreapp.dev")).toBeFalsy());
        test("Starts with '.'", () => expect((0, utils_1.isValidEmail)(".a@moreapp.dev")).toBeFalsy());
        test("Ends with a '.'", () => expect((0, utils_1.isValidEmail)("a.@moreapp.dev")).toBeFalsy());
        test("Local part contains whitespace", () => expect((0, utils_1.isValidEmail)("a b@moreapp.dev")).toBeFalsy());
    });
});
describe("parseDynamicRecipients", () => {
    test("should parse all type of data (root, object, array)", () => {
        const fields = [
            { uid: "UID-root", properties: { data_name: "customer" } },
            { uid: "UID-object", properties: { data_name: "vendor" } },
            { uid: "UID-array", properties: { data_name: "contacts" } },
        ];
        expect((0, utils_1.parseDynamicRecipients)(["UID-root", "UID-object.email", "UID-array"], fields, {
            customer: "customer@example.com",
            vendor: { id: 1, email: "vendor@example.com" },
            contacts: ["contact1@example.com", "contact2@example.com"],
        })).toEqual([
            "customer@example.com",
            "vendor@example.com",
            "contact1@example.com",
            "contact2@example.com",
        ]);
    });
});
describe("getDataForDataName", () => {
    test("should return (nested) values in objects based on dataName", () => {
        let data = {
            name: "John",
            age: 10,
            address: {
                street: "Main Street",
                city: "New York",
                location: {
                    longitude: 10,
                    latitude: 10,
                },
            },
            "flat.test": "hi",
        };
        expect((0, utils_1.getDataForDataName)(data, "name")).toBe("John");
        expect((0, utils_1.getDataForDataName)(data, "age")).toBe(10);
        expect((0, utils_1.getDataForDataName)(data, "address.city")).toBe("New York");
        expect((0, utils_1.getDataForDataName)(data, "address.location.longitude")).toBe(10);
        expect((0, utils_1.getDataForDataName)(data, "flat.test")).toBe("hi");
        expect((0, utils_1.getDataForDataName)(data, "unknown")).toBe(undefined);
        expect((0, utils_1.getDataForDataName)(data, "unknown.nested")).toBe(undefined);
        expect((0, utils_1.getDataForDataName)(data, "address.unknown")).toBe(undefined);
        expect((0, utils_1.getDataForDataName)(data, "flat..")).toBe(undefined);
        expect((0, utils_1.getDataForDataName)(data, ".")).toBe(undefined);
    });
});
